YARP 3.2.1 (2019-09-25)                                                {#v3_2_1}
=======================

[TOC]

YARP 3.2.1 Release Notes
========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v3.2.1%22).


Bug Fixes
---------

### Carriers

##### `mjpeg`

* Fixed `mjpeg` carrier using BGR images (#2060, #2061).


### Devices

##### `MultipleAnalogSensorsRemapper`

* Fixed `getTemperatureSensorMeasure` method (#2056, #2058).


### Tools

##### `yarpidl_thrift`

* Fixed deserialization for map types (#2054).

##### `yarprun`

* Fixed remote commands execution getting stucks with no answer (#2091).


### GUIs

##### `yarpdataplayer`

* Fixed internal virtual timing in the yarpdataplayer as timestamps were not
  consistent (#2049, #2052).

##### `yarpmanager`



Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v3.2.0..v3.2.1`):

```
   170	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     4	Nicolò Genesio <nicolo.genesio@iit.it>
     2	Vadim Tikhanoff <vadim.tikhanoff@iit.it>
     1	Giovanni Saponaro <gsaponaro@isr.tecnico.ulisboa.pt>
     1	Valentina Gaggero <valentina.gaggero@iit.it>
```
